@@ -5,14 +5,14 @@
 # Created: 2007-Jan-28 16:03 (EST)
 # Function: BER encoding/decoding (also: CER and DER)
 #
-# $Id: BER.pm,v 1.9 2007/03/06 02:50:10 jaw Exp $
+# $Id: BER.pm,v 1.11 2008/05/31 18:43:11 jaw Exp $
 
 # references: ITU-T x.680 07/2002  -  ASN.1
 # references: ITU-T x.690 07/2002  -  BER
 
 package Encoding::BER;
 use vars qw($VERSION);
-$VERSION = '1.00';
+$VERSION = '1.02';
 use Carp;
 use strict;
 # loaded on demand if needed:
@@ -452,7 +452,7 @@ sub encode_int {
     my @i;
     my $big;
 
-    if( defined &Math::BigInt::new ){
+    if( _have_math_bigint() ){
 	# value is a bigint or a long string
 	$big = 1 if (ref $val && $val->can('as_hex')) || length($val) > 8;
     }
@@ -496,8 +496,8 @@ sub encode_uint {
     
     my @i;
     my $big;
-    
-    if( defined &Math::BigInt::new ){
+
+    if( _have_math_bigint() ){
 	# value is a bigint or a long string
 	$big = 1 if (ref $val && $val->can('bcmp')) || length($val) > 8;
     }
@@ -1275,7 +1275,7 @@ sub part_decode_int {
 
     my $val;
     my $big;
-    $big = 1 if defined &Math::BigInt::new && length($data) > 4;
+    $big = 1 if _have_math_bigint() && length($data) > 4;
 
     if( $big ){
 	my $sign = unpack('c', $data) < 0;
@@ -1421,6 +1421,14 @@ sub decode_unknown {
     };    
 }
 
+sub _have_math_bigint {
+
+    return unless defined &Math::BigInt::new;
+    return unless defined &Math::BigInt::is_neg;
+
+    1;
+}
+    
 ################################################################
 
 sub hexdump {
